@@ -12,7 +12,7 @@
 //
 //
 
-// $Id: dig.c 228 2010-03-23 12:09:17Z jessekornblum $
+// $Id: dig.c 244 2010-12-14 20:19:52Z jessekornblum $
 
 #include "main.h"
 
@@ -280,7 +280,7 @@ static int is_junction_point(state *s, TCHAR *fn)
 
 
 #ifdef _WIN32
-  WIN32_FIND_DATAW FindFileData;
+  WIN32_FIND_DATA FindFileData;
   HANDLE hFind;
 
   hFind = FindFirstFile(fn, &FindFileData);
@@ -481,7 +481,7 @@ static int file_type(state *s, TCHAR *fn)
     return stat_unknown;
   }
 
-  s->total_bytes = sb.st_size;
+  s->stat_bytes = sb.st_size;
 
   // On Win32 this should be the creation time, but on all other systems
   // it will be the change time.
@@ -597,7 +597,7 @@ static int should_hash(state *s, TCHAR *fn)
 
   // We must reset the number of bytes in each file processed
   // so that we can tell if fstat reads the number successfully
-  s->total_bytes = UNKNOWN_FILE_SIZE;
+  s->stat_bytes = UNKNOWN_FILE_SIZE;
   s->timestamp   = 0;
 
   type = file_type(s,fn);
@@ -650,7 +650,7 @@ int process_win32(state *s, TCHAR *fn)
 {
   int rc, status = STATUS_OK;
   TCHAR *asterisk, *question, *tmp, *dirname, *new_fn;
-  WIN32_FIND_DATAW FindFileData;
+  WIN32_FIND_DATA FindFileData;
   HANDLE hFind;
 
   //  print_status("Called process_win32(%S)", fn);
