@@ -1,7 +1,7 @@
 
 #include "main.h"
 
-// $Id: display.c 164 2009-01-09 16:59:36Z jessekornblum $
+// $Id: display.c 248 2010-12-15 02:39:55Z jessekornblum $
 
 static void display_banner(state *s)
 {
@@ -68,7 +68,14 @@ int display_hash_simple(state *s)
   if ( ! (s->banner_displayed))
     display_banner(s);
 
-  printf ("%"PRIu64",", s->bytes_read);
+  // In piecewise mode the size of each 'file' is the size
+  // of the block it came from. This is important when doing an
+  // audit in piecewise mode. In all other cases we use the 
+  // total number of bytes from the file we *actually* read
+  if (s->mode & mode_piecewise)
+    printf ("%"PRIu64",", s->bytes_read);
+  else
+    printf ("%"PRIu64",", s->actual_bytes);
 
   for (i = 0 ; i < NUM_ALGORITHMS ; ++i)
   {
