@@ -1,16 +1,24 @@
-
-/* $Id: tchar-local.h 182 2009-03-27 02:20:51Z jessekornblum $ */
-
 #ifndef __TCHAR_LOCAL_H
 #define __TCHAR_LOCAL_H
 
+// $Id: tchar-local.h 241 2010-11-25 20:28:34Z jessekornblum $
 
-/* Unicode support */
+// Unicode support 
 #ifdef _WIN32
 
 // This says that we require Windows NT 4.0 to run
 #define _WIN32_WINNT 0x0400
 
+// These defines are required to enable Unicode support.
+// Some of the build scripts define them for us, some don't.
+// We use conditional defines to avoid redefining them.
+#ifndef UNICODE
+# define UNICODE
+#endif
+#ifndef _UNICODE
+# define _UNICODE
+#endif
+
 # include <windows.h>
 # include <wchar.h>
 # include <tchar.h>
