@@ -1,6 +1,6 @@
 #include "main.h"
 
-// $Id: display.c 182 2009-03-27 02:20:51Z jessekornblum $ 
+// $Id: display.c 244 2010-12-14 20:19:52Z jessekornblum $ 
 
 static void display_size(state *s)
 {
@@ -12,13 +12,13 @@ static void display_size(state *s)
     // When in CSV mode we always display the full size
     if (s->mode & mode_csv)
     {
-      printf ("%"PRIu64",", s->bytes_read);
+      printf ("%"PRIu64",", s->actual_bytes);
     }
     // We reserve ten characters for digits followed by two spaces
     else if (s->bytes_read > 9999999999LL)
       printf ("9999999999  ");
     else
-      printf ("%10"PRIu64"  ", s->bytes_read);      
+      printf ("%10"PRIu64"  ", s->actual_bytes);      
   }	
 }
 
@@ -83,6 +83,14 @@ int display_hash(state *s)
 {
   if (NULL == s)
     return TRUE;
+  
+  if (s->mode & mode_triage)
+  {
+    printf ("\t%s\t", s->hash_result);
+    display_filename(stdout,s->full_name);
+    make_newline(s);
+    return FALSE;
+  }    
 
   // We can't call display_size here because we don't know if we're
   // going to display *anything* yet. If we're in matching mode, we
