@@ -9,7 +9,7 @@
 // WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $Id: main.c 228 2010-03-23 12:09:17Z jessekornblum $
+// $Id: main.c 241 2010-11-25 20:28:34Z jessekornblum $
 
 #include "main.h"
 
@@ -57,6 +57,9 @@ static void usage(void)
 
 static void check_flags_okay(state *s)
 {
+  if (NULL == s)
+    exit (STATUS_USER_ERROR);
+
   sanity_check(s,
 	       ((s->mode & mode_match) || (s->mode & mode_match_neg)) &&
 	       !s->hashes_loaded,
@@ -90,6 +93,9 @@ static void check_flags_okay(state *s)
 
 static void check_matching_modes(state *s)
 {
+  if (NULL == s)
+    exit (STATUS_USER_ERROR);
+
   sanity_check(s,
 	       (s->mode & mode_match) && (s->mode & mode_match_neg),
 	       "Regular and negative matching are mutually exclusive.");
@@ -99,10 +105,13 @@ static void check_matching_modes(state *s)
 static int process_command_line(state *s, int argc, char **argv)
 {
   int i;
+
+  if (NULL == s)
+    return TRUE;
   
   while ((i = getopt(argc,
 		     argv,
-		     "f:I:i:M:X:x:m:o:A:a:tnwczsSp:erhvV0lbkqU")) != -1) { 
+		     "f:I:i:M:X:x:m:o:A:a:tnwczsSp:erhvV0lbkqZ")) != -1) { 
     switch (i) {
 
     case 'f':
@@ -136,9 +145,11 @@ static int process_command_line(state *s, int argc, char **argv)
 
       break;
 
-    case 'q': 
-      s->mode |= mode_quiet; 
+
+    case 'Z':
+      s->mode |= mode_triage;
       break;
+
     case 't':
       s->mode |= mode_timestamp;
       MD5DEEP_ALLOC(char,s->time_str,MAX_TIME_STRING_LENGTH);
@@ -163,14 +174,11 @@ static int process_command_line(state *s, int argc, char **argv)
       add_hash(s,optarg,optarg);
       s->hashes_loaded = TRUE;
       break;
-      
-    case 'l': 
-      s->mode |= mode_relative; 
-      break;
 
-    case 'b': 
-      s->mode |= mode_barename; 
-      break;
+
+
+
+
 
     case 'o': 
       s->mode |= mode_expert; 
@@ -228,6 +236,18 @@ static int process_command_line(state *s, int argc, char **argv)
       s->mode |= mode_asterisk;
       break;
 
+    case 'b': 
+      s->mode |= mode_barename; 
+      break;
+      
+    case 'l': 
+      s->mode |= mode_relative; 
+      break;
+
+    case 'q': 
+      s->mode |= mode_quiet; 
+      break;
+
     case 'h':
       usage();
       exit (STATUS_OK);
@@ -286,6 +306,9 @@ static int prepare_windows_command_line(state *s)
   int argc;
   TCHAR **argv;
 
+  if (NULL == s)
+    return TRUE;
+
   argv = CommandLineToArgvW(GetCommandLineW(),&argc);
   
   s->argc = argc;
@@ -303,6 +326,9 @@ int process_input_list(state *s)
   FILE * handle = fopen(s->input_list,"rb");
   char * fn;
 
+  if (NULL == s)
+    return TRUE;
+
   t_name = (TCHAR *)malloc(sizeof(TCHAR) * PATH_MAX);
   if (NULL == t_name)
     return TRUE;
@@ -442,11 +468,11 @@ int main(int argc, char **argv)
     free(cwd);
   }
 
-  /* We only have to worry about checking for unused hashes if one 
-     of the matching modes was enabled. We let the display_not_matched
-     function determine if it needs to display anything. The function
-     also sets our return values in terms of inputs not being matched
-     or known hashes not being used */
+  // We only have to worry about checking for unused hashes if one 
+  // of the matching modes was enabled. We let the display_not_matched
+  // function determine if it needs to display anything. The function
+  // also sets our return values in terms of inputs not being matched
+  // or known hashes not being used
   if ((s->mode & mode_match) || (s->mode & mode_match_neg))
     s->return_value = finalize_matching(s);
 
